@@ -1,10 +1,9 @@
 # LGRID & EGRID
-import os
-from tkinter import Entry, Label
+from tkinter import Button, Entry, Label
 
 
 def lgrid(self, text, gridcol, gridrow, **args):
-    """  Label Maker
+    """Label Maker for quick labels in a GUI window.
     Example :
         lgrid(root,'text to enter',0,0,**args)
 
@@ -16,9 +15,15 @@ def lgrid(self, text, gridcol, gridrow, **args):
 
 
 def egrid(self, col, row, *args, **kwarg):
-    """ Entry Maker
+    """Entry Maker for a quick entry in a GUI window.
     Example:
     egrid(root,1,0)
     """
     e1 = Entry(self)
     e1.grid(column=col, row=row)
+
+
+def bgrid(self, text, col, row, *args, **kwarg):
+    """Button Maker for quick entry in a grid"""
+    btn1 = Button(self, text=text, command=quit)
+    btn1.grid(column=col, row=row)
